@@ -1,9 +1,9 @@
 package Acme::Matrix;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use 5.006; use strict; use warnings;
 use Term::ReadKey; 
 
-our (@WORDS, @CHARS);
+our (@WORDS, @CHARS, @COLOURS);
 BEGIN {
 	$SIG{INT} = \&shutdown;	
 	@WORDS = (
@@ -45,8 +45,10 @@ BEGIN {
 		ザ ジ ズ ゼ ゾ タ チ ツ テ ト ダ ヂ ヅ デ ド ナ ニ ヌ ネ ノ
  		ハ ヒ フ ヘ ホ バ ビ ブ ベ ボ パ ピ プ ペ ポ マ ミ ム メ モ
 	/;
+ 	@COLOURS = ( 28, 34, 35, 40, 41, 46, 47, 48, 48, 82, 83, 0 );
 }
 
+
 sub start {
 	my ($pkg, %args) = @_;
 	@WORDS = @{$args{words}} if ($args{words});
@@ -61,9 +63,10 @@ sub start {
 	while (1) {
 		for (0..$wchar) {
 			if (int(rand(5) + 0.5) > 4) {
+				my $i = 0;
 				push @{$word_lines{$_}}, (int(rand(1) + 0.5)) 
-					? "\033[38;5;34m" . $CHARS[int(rand(scalar @CHARS))]
-					: map { "\033[38;5;46m" . $_ } @{ $WORDS[int(rand(scalar @WORDS))] };
+					? sprintf("\033[38;5;%sm%s", $COLOURS[int(rand(scalar @COLOURS))], $CHARS[int(rand(scalar @CHARS))])
+					: map { sprintf("\033[38;5;%sm%s", $COLOURS[$i++], $_) } @{ $WORDS[int(rand(scalar @WORDS))] }, "  ";
 			}
 			print shift(@{$word_lines{$_}}) || "  ";
 		}
@@ -78,13 +81,17 @@ sub shutdown {
 	exit;
 }
 
+__END__
+
+1;
+
 =head1 NAME
 
 Acme::Matrix - Heavenly digital rain
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
